"""
This file define grepy as a module.
"""

from .core import main

# Package Metadata

__package_name__ = "grepy"
__version__ = "0.1.0"
__authors__ = ["Eliaz Bobadilla <eliaz.bobadilladev@gmail.com>"]
__author_email__ = "eliaz.bobadilladev@gmail.com"
__url__ = "https://github.com/UltiRequiem/grepy"
